@@ -7,10 +7,10 @@ import datetime as dt
 import functools
 import hashlib
 import inspect
-from typing import Any, Callable, Iterable, Optional
 
 import cloudpickle
 from beartype import beartype
+from beartype.typing import Any, Callable, Iterable, Optional
 from icontract import require
 
 from .serializers import CloudPickleSerializer, Serializer
@@ -123,9 +123,9 @@ class Cache:
         if ignore is not None:
             arg_dict = {k: v for k, v in arg_dict.items() if k not in ignore}
 
-        return hash_it(inspect.getsource(fn), type(serializer), arg_dict)
+        return hash_it(inspect.getsource(fn), type(serializer).__name__, arg_dict)
 
-    def _get_filename(self, fn: callable, key: str, serializer: Serializer) -> str:
+    def _get_filename(self, fn: Callable, key: str, serializer: Serializer) -> str:
         return f"{fn.__name__}-{key}.{serializer.extension}"
 
 
